@@ -599,6 +599,10 @@ class AdaptiveComfortMapEntryPoint(DAG):
         self, comfort_model='adaptive', run_period=run_period
     ) -> List[Dict]:
         return [
+            {
+                'from': MapResultInfo()._outputs.viz_config_file,
+                'to': 'metrics/config.json'
+            },
             {
                 'from': MapResultInfo()._outputs.temperature_info,
                 'to': 'results/temperature/results_info.json'
